==> Pyrogram-1.0.2-py3-none-any.whl: pyrogram/raw/base/messages/all_stickers.py <==
#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-2020 Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from typing import Union
from pyrogram import raw
from pyrogram.raw.core import TLObject

AllStickers = Union[raw.types.messages.AllStickers, raw.types.messages.AllStickersNotModified]


# noinspection PyRedeclaration
class AllStickers(TLObject):  # type: ignore
    """This base type has 2 constructors available.

    Constructors:
        .. hlist::
            :columns: 2

            - :obj:`messages.AllStickers <pyrogram.raw.types.messages.AllStickers>`
            - :obj:`messages.AllStickersNotModified <pyrogram.raw.types.messages.AllStickersNotModified>`

    See Also:
        This object can be returned by 2 methods:

        .. hlist::
            :columns: 2

            - :obj:`messages.GetAllStickers <pyrogram.raw.functions.messages.GetAllStickers>`
            - :obj:`messages.GetMaskStickers <pyrogram.raw.functions.messages.GetMaskStickers>`
    """

    QUALNAME = "pyrogram.raw.base.messages.AllStickers"

==> Pyrogram-1.0.4-py3-none-any.whl: pyrogram/raw/base/messages/all_stickers.py <==
#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-2020 Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from typing import Union
from pyrogram import raw
from pyrogram.raw.core import TLObject

AllStickers = Union[raw.types.messages.AllStickers, raw.types.messages.AllStickersNotModified]


# noinspection PyRedeclaration
class AllStickers:  # type: ignore
    """This base type has 2 constructors available.

    Constructors:
        .. hlist::
            :columns: 2

            - :obj:`messages.AllStickers <pyrogram.raw.types.messages.AllStickers>`
            - :obj:`messages.AllStickersNotModified <pyrogram.raw.types.messages.AllStickersNotModified>`

    See Also:
        This object can be returned by 2 methods:

        .. hlist::
            :columns: 2

            - :obj:`messages.GetAllStickers <pyrogram.raw.functions.messages.GetAllStickers>`
            - :obj:`messages.GetMaskStickers <pyrogram.raw.functions.messages.GetMaskStickers>`
    """

    QUALNAME = "pyrogram.raw.base.messages.AllStickers"
